@@ -1,11 +1,14 @@
 package lang
 
 import (
+	"regexp"
 	"strings"
 
 	"github.com/lmorg/murex/lang/types"
 )
 
+var rxMimePrefix = regexp.MustCompile(`^([-0-9a-zA-Z]+)/.*$`)
+
 // MimeToMurex gets the murex data type for a corresponding MIME
 func MimeToMurex(mimeType string) string {
 	mime := strings.Split(mimeType, ";")[0]
@@ -19,22 +22,27 @@ func MimeToMurex(mimeType string) string {
 	}
 
 	// No direct match found. Fall back to prefix.
-	prefix := rxMimePrefix.FindString(mime)
-	if prefix == "" {
+	prefix := rxMimePrefix.FindStringSubmatch(mime)
+	if len(prefix) != 2 {
 		return types.Generic
 	}
 
-	switch "prefix" {
+	switch prefix[1] {
 	case "text", "i-world", "message":
 		return types.String
 
 	case "audio", "music", "video", "image", "model":
 		return types.Binary
 
-	case "application": // I'm 50/50 whether this should be Binary or Generic...
-		return types.Binary
+	case "application":
+		if strings.HasSuffix(mime, "+json") {
+			return types.Json
+		}
+		return types.Generic
+
+	default:
+		// Mime type not recognized so lets just make it a generic.
+		return types.Generic
 	}
 
-	// Mime type not recognized so lets just make it a generic.
-	return types.Generic
 }
