@@ -26,7 +26,7 @@ func TestHintCodeBlock(t *testing.T) {
 			HintRx: `^out "bob"$`,
 		},
 		{
-			Block: `{ $out "bob" }`,
+			Block:  `{ $out "bob" }`,
 			HintRx: `^Block returned false`,
 		},
 	}
@@ -34,7 +34,7 @@ func TestHintCodeBlock(t *testing.T) {
 	count.Tests(t, len(tests))
 
 	lang.InitEnv()
-	defaults.Defaults(lang.ShellProcess.Config, false)
+	defaults.Config(lang.ShellProcess.Config, false)
 	debug.Enabled = true
 
 	for i, test := range tests {
